@@ -8,7 +8,7 @@ use Carp qw( croak );
 use Exporter ();
 
 # ABSTRACT: Portably generate config for any shell
-our $VERSION = '0.25'; # VERSION
+our $VERSION = '0.26'; # VERSION
 
 
 sub new
@@ -120,7 +120,7 @@ sub _value_escape_win32
 {
   my $value = shift() . '';
   $value =~ s/%/%%/g;
-  $value =~ s/([&^|<>])/^$1/g;
+  $value =~ s/([&^|<>()])/^$1/g;
   $value =~ s/\n/^\n\n/g;
   $value;
 }
@@ -149,7 +149,7 @@ my %ps = ( # microsoft would have to be different
 sub _value_escape_powershell
 {
   my $value = shift() . '';
-  $value =~ s/(["'`\$#])/`$1/g;
+  $value =~ s/(["'`\$#()])/`$1/g;
   $value =~ s/([\0\a\b\f\r\n\t])/$ps{$1}/eg;
   $value;
 }
@@ -340,7 +340,7 @@ sub generate
       }
       elsif($shell->is_power)
       {
-        $buffer .= "function $args->[0] { $args->[1] \$args }\n";
+        $buffer .= sprintf("function %s { %s \$args }\n", $args->[0], _value_escape_powershell($args->[1]));
       }
       elsif($shell->is_fish)
       {
@@ -368,7 +368,7 @@ sub generate_file
 
 *import = \&Exporter::import;
 
-our @EXPORT_OK = qw( win32_space_be_gone );
+our @EXPORT_OK = qw( win32_space_be_gone cmd_escape_path powershell_escape_path );
 
 
 *_win_to_posix_path = $^O =~ /^(cygwin|msys)$/ ? \&Cygwin::win_to_posix_path : sub { $_[0] };
@@ -380,6 +380,18 @@ sub win32_space_be_gone
   map { /\s/ ? _win_to_posix_path(Win32::GetShortPathName(_posix_to_win_path($_))) : $_ } @_;
 }
 
+
+sub cmd_escape_path
+{
+  map { _value_escape_win32($_) } @_;
+}
+
+
+sub powershell_escape_path
+{
+  map { _value_escape_powershell($_) } @_;
+}
+
 1;
 
 __END__
@@ -394,7 +406,7 @@ Shell::Config::Generate - Portably generate config for any shell
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -664,6 +676,10 @@ file system objects without spaces.  To do this
 C<Win32::GetShortPathName()> is used on to find alternative
 path names without spaces.
 
+NOTE that this breaks when Windows is told not to create
+short (C<8+3>) filenames; see L<http://www.perlmonks.org/?node_id=333930>
+for a discussion of this behaviour.
+
 In addition, on just C<Cygwin>:
 
 The input paths are first converted from POSIX to Windows paths
@@ -674,6 +690,16 @@ Elsewhere:
 
 Returns the same list passed into it
 
+=head2 cmd_escape_path( @path_list )
+
+Given a list of directory paths (or filenames), this will
+return an equivalent list of paths escaped for cmd.exe and command.com.
+
+=head2 powershell_escape_path( @path_list )
+
+Given a list of directory paths (or filenames), this will
+return an equivalent list of paths escaped for PowerShell.
+
 =head1 CAVEATS
 
 The test suite tests this module's output against the actual
@@ -732,7 +758,11 @@ Patches welcome for your favorite shell / operating system.
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+Contributors:
+
+Brad Macpherson (BRAD, brad-mac)
 
 =head1 COPYRIGHT AND LICENSE
 
